#
# spec file for package k3sup
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           k3sup
Version:        0.13.8
Release:        1.2
Summary:        Bootstrap Kubernetes with k3s over SSH < 1 min
License:        MIT
URL:            https://github.com/alexellis/k3sup
Source:         k3sup-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.23

%description
k3sup is a light-weight utility to get from zero to KUBECONFIG with k3s on any
local or remote VM. All you need is ssh access and the k3sup binary to get
kubectl access immediately.
The tool is written in Go and is cross-compiled for Linux, Windows, MacOS and
even on Raspberry Pi.
How do you say it? Ketchup, as in tomato.

%prep
%autosetup -p 1 -a 1

%build
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-X main.Version=%{version}"

%install
# Install the binary.
install -D -m 0755 %{name} "%{buildroot}/%{_bindir}/%{name}"

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%changelog
* Tue Jan 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.13.8:
  * Update Go version, GitHub Actions and vendor
* Tue Jan 21 2025 opensuse_buildservice@ojkastl.de
- Update to version 0.13.7:
  * Support ssh-key for k3sup plan
* Mon Jun 10 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.13.6:
  * Update to message in get.sh
  * Update support message
  * Update example with three hosts
  * fix example and make it valid JSON
* Fri Feb  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.13.5:
  * Add --no-extra flag to join command
  * Update go-execute and cobra
* Fri Feb  2 2024 opensuse_buildservice@ojkastl.de
- Update to version 0.13.4:
  * Bump golang.org/x/crypto from 0.13.0 to 0.17.0
  * Update README.md
* Fri Oct 27 2023 kastl@b1-systems.de
- Update to version 0.13.3:
  * Add --server-k3s-extra-args for disabling traefik etc
* Fri Oct 27 2023 kastl@b1-systems.de
- Update to version 0.13.2:
  * Add notes to README for k3sup plan
  * Use node-token from an env-var instead of a file
  * Use an env-var for the node-token instead of a file
  * Update examples for k3sup plan
  * Move temporary file deletion into a defer
  * Add plan and node-token commands
  * Fix typo
  * Alteration to support message
* Fri Sep 15 2023 kastl@b1-systems.de
- Update to version 0.13.1:
  * Update vendor
  * Update to go-execute v2
  * chore: remove refs to deprecated io/ioutil
* Thu Aug 31 2023 andrea.manzini@suse.com
- Update to version 0.13.0:
  * Ignore gofmt errors from vendor folder
  * Remove usage of deprecated errors package
  * Remove rebuild and cgo
  * Update to Go 1.20
  * Format some of the code, comment out unused line
  * Add --tls-san for join command for servers
  * Update README.md
  * Update dependencies
  * Print agent host/IP in join command
  * Change streaming behaviour when joining nodes
* Tue May 30 2023 Johannes Kastl <kastl@b1-systems.de>
- use -buildmode=pie and BuildRequire go1.19
* Tue May 30 2023 kastl@b1-systems.de
- Update to version 0.12.12:
  * Rename no-deploy to disable
* Tue May 30 2023 kastl@b1-systems.de
- Update to version 0.12.11:
  * Bump GH Workflows to use Go 1.19
  * Update publish.yaml
- BuildRequire go1.18
* Tue May 30 2023 kastl@b1-systems.de
- Update to version 0.12.10:
  * Fix tests with extra parameter
* Tue May 30 2023 kastl@b1-systems.de
- Update to version 0.12.9:
  * Add server-url for use with HA IP
  * Only print out stderr with --local if there's a non-zero exit
* Tue May 30 2023 kastl@b1-systems.de
- Update to version 0.12.8:
  * Document the ready command
* Wed Oct  5 2022 kastl@b1-systems.de
- Update to version 0.12.7:
  * Fix issue with string being quoted in ready command
* Wed Oct  5 2022 kastl@b1-systems.de
- Update to version 0.12.6:
  * Fix ready command
* Tue Oct  4 2022 kastl@b1-systems.de
- Update to version 0.12.5:
  * Add experimental ready feature
* Tue Oct  4 2022 kastl@b1-systems.de
- Update to version 0.12.4:
  * Fix issue with join token for Windows users:
  * Remove SWAG
  * Less is more
  * Fix #314
  * Clarify what sponsorship entails
  * Clarify expectations
* Tue Oct  4 2022 kastl@b1-systems.de
- Update to version 0.12.3:
  * Fix parsing of host field
* Tue Oct  4 2022 kastl@b1-systems.de
- Update to version 0.12.2:
  * Add build for darwin arm64 and adjust get accordingly
  * Update examples for install, join and main command
  * Update .DEREK.yml file
  * Remove old packages from apps feature
  * Make data-dir configurable for getting node token
* Tue Oct  4 2022 kastl@b1-systems.de
- Update to version 0.12.1:
  * Alter the support message printed in k3sup
  * Increase minimum 32-bit arm version
  * Upgrade golang.org packages
  * Update ISSUE_TEMPLATE.md
* Thu Jul 14 2022 rombert@apache.org
- Update to version 0.12.0:
  * Update Go crypo libraries and migrate to Go 1.18
  * Add k3s and LXC post
  * Use explicit path for SUCCESS_CMD
  * Fix 376
  * Add k3s check command
  * Update README.md
  * Add sponsoring card back to README due to lack of sponsors
  * Update README.md
  * Update PULL_REQUEST_TEMPLATE.md
  * Update .DEREK.yml
  * Mention k3s-channel flag
  * Remove vendoring in CI
  * Update go version for M1 Darwin support in CI
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.11.2:
  * Upgrade for K3s HA and fix for merging config on Windows
    PR #360 Expand --local-path string for Windows by @alexellis
    PR #359 Added instructions for using --server-user by @cbrachem
    PR #355 Add --token to HA external datastore command by @Waterdrips
    PR #354 Build badge with Github CI link by @rashedkvm
    PR #353 Added GitHub Actions build status using workflow name by @rashedkvm
    PR #340 Add a blog post to the README by @adyanth
  * Commits
  - b3b7106 Expand --local-path string for Windows by @sralloza
  - 73b7f03 Added instructions for using --server-user by @cbrachem
  - 080b9cf Add --token to HA external datastore command by @Waterdrips
  - 38c1dc5 Update README.md by @alexellis
  - 99811f1 Update README.md by @alexellis
  - 57e86ae Update README.md by @alexellis
  - cdcebfb Build badge with Github CI link by @rashedkvm
  - 40f3ff6 Added build badge using workflow name by @rashedkvm
  - 2a52d3c Update README.md by @alexellis
  - 9b6964f Update README.md by @alexellis
  - b53a140 Update README.md by @alexellis
  - 9717ee3 Add a blog post to the README by @adyanth
  - 4c0bbd5 Update pre-reqs in ToC by @alexellis
  - 89d15f2 Update README with note on passwordless sudo by @alexellis
  - 2d28f9e Update README.md by @alexellis
  - 75b863e Update ISSUE_TEMPLATE.md by @alexellis
  - 26db404 Update .DEREK.yml by @alexellis
* Tue Jan  4 2022 kastl@b1-systems.de
- Update to version 0.11.1:
  * Set the k3s version to stable
  * Commits:
  - 95cf0b1 Set the k3s version to stable by @alexellis
  - 3315af5 Update README.md by @alexellis
  - 6fde5ef Fix two ToC links by @alexellis
  - 337fef3 Update headings and add 2fa note by @alexellis
* Mon May 17 2021 kastl@b1-systems.de
- Update to version 0.11.0:
  * Update README.md
  * Fix two ToC links
  * Update headings and add 2fa note
  * Handle absense of SSH_AUTH_SOCK and agent errors
  * Add ssh-agent with fall-through to join command.
  * Transparently use ssh-agent on linux/darwin
  * Update ToC and switch out sponsors image
  * Update troubleshooting section
  * Fix 321 for local skip-install option
  * Update ISSUE_TEMPLATE.md
* Mon May 17 2021 Johannes Kastl <kastl@b1-systems.de>
- initial version of the package k3sup
